@@ -11,18 +11,14 @@ nlp = spacy.load("en")
 
 
 class CleanText:
-    def __init__(self):
-        pass
+    # def __init__(self):
+    #     self.all_names = pd.read_pickle("data/all_names")
 
-    # TODO: Fix data import here
-    # self.all_names = pd.read_pickle("data/all_names")
-    # def remove_names(self, text):
-    #     cleaned_text = text
-    #     for i, row in self.all_names.iterrows():
-    #         cleaned_text = re.sub(
-    #             row["name"] + "[^\w\s]*[\s]+", "<NAME> ", cleaned_text
-    #         )
-    #     return cleaned_text
+    def remove_names(self, text):
+        cleaned_text = text
+        for i, row in self.all_names.iterrows():
+            cleaned_text = re.sub(row["name"] + "[^\w\s]*[\s]+", " ", cleaned_text)
+        return cleaned_text
 
     def remove_links(self, text):
         """
@@ -41,16 +37,11 @@ class CleanText:
             cleaned_text,
         )
         for link in links_found:
-            cleaned_text = cleaned_text.replace(link, "<LINK>")
+            cleaned_text = cleaned_text.replace(link, "")
         return cleaned_text
 
-    # TODO: Fix spacy load 'en' issue
     def lematize(self, text):
         """
-        Run `python -m spacy download en` in the terminal first.
-
-        Then, include `nlp = spacy.load("en")` in your code.
-
         Parameters
         --------
         text: str
@@ -117,11 +108,11 @@ class CleanText:
 
         Parameters
         --------
-        DataFrame
+        df: DataFrame
 
         Returns
         --------
-        DataFrame
+        df: DataFrame
 
         """
         df.rename(columns=lambda x: x.strip().replace(" ", "_").lower(), inplace=True)
@@ -133,11 +124,11 @@ class CleanText:
 
         Parameters
         --------
-        DataFrame
+        df: DataFrame
 
         Returns
         --------
-        DataFrame
+        df: DataFrame
 
         """
         df = df.loc[:, ~df.columns.duplicated()]
@@ -149,7 +140,7 @@ class CleanText:
 
         Parameters
         --------
-        DataFrame
+        df: DataFrame
         col: str
             Column to change the dtype for
         desired_dt: str
@@ -157,7 +148,7 @@ class CleanText:
 
         Returns
         --------
-        DataFrame
+        df: DataFrame
 
         """
         if desired_dt in ("float", "int"):
